@@ -25,12 +25,12 @@
 var NAVTREE =
 [
   [ "PipeWire", "index.html", [
-    [ "PipeWire API", "page_api.html", "page_api" ],
     [ "Overview", "page_overview.html", null ],
-    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
     [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
-    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
+    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
     [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
+    [ "PipeWire API", "page_api.html", "page_api" ],
+    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
     [ "Modules", "modules.html", "modules" ],
     [ "Data Structures", "annotated.html", [
       [ "Data Structures", "annotated.html", "annotated_dup" ],
@@ -58,26 +58,26 @@ var NAVTREEINDEX =
 "annotated.html",
 "globals_defs_p.html",
 "globals_l.html",
-"group__pw__core.html#ga06c0275ea988bc37118882895ec03433",
-"group__pw__impl__metadata.html#ga8bbf7f9227bbdab72bfd6f763a3e005d",
-"group__pw__log.html#ga79ae1a7ed5197195c18fb87ef5e175cb",
-"group__pw__properties.html#ga2a74f501f08394c09018d9c29450f2f4",
-"group__pw__session__manager.html#gaca1ae64643a150fbe2878067856b629a",
-"group__spa__buffer.html#ga19c6e5afa926fbda88e8b236df740356",
-"group__spa__dict.html#ga9f7b5a7c12bdbfda65275270dcb72abd",
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64",
-"group__spa__node.html#ggae111175d27c9aa0b465b826bc55c9be1ad73df09f7d608ee04395ad8162417fcd",
-"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a7e8f1b1bedb23577708a8f224e6f5dea",
-"group__spa__param.html#gga741ca54fc7f93308779660120bbed31ea3feca05cc1d25a940d6dcb5096fd84a2",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea68d5146155e4ed0c97a9c2a9655282ef",
-"group__spa__pod.html#ga9c600d17cc240567be847b7f5f586bee",
-"group__spa__types.html#gga99fb83031ce9923c84392b4e92f956b5ab2f26930a251f5d048dfebcc46e4f736",
-"page_streams.html#sec_connect",
-"structpw__factory__info.html#aa930c209d3ae55baeaebff7edc38a02b",
-"structpw__protocol__client.html#a9ce571a5bc950b3309d0dbd2a55e501f",
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0",
-"structspa__node.html#a898fcb8b2d37d7c42fd9c15d1f8c1ed7",
-"structspa__video__colorimetry.html#ae40f82c41e61be82a9697a872d83479e"
+"group__pw__core.html",
+"group__pw__impl__metadata.html#ga400e2176366436ac8752c563400a8eda",
+"group__pw__log.html#ga073d2e07bc95bf80bb43e9d863bd2c8e",
+"group__pw__profiler.html#ga2270ff65dd05ec8d44b575d345b34ef7",
+"group__pw__session__manager.html#gab48a226b48e006093ea7849eada7a806",
+"group__spa__ansi.html#gad9ac3e26ccd0b443d1dcfcbbb6222b3e",
+"group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b",
+"group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a",
+"group__spa__node.html#gafda72bd4c75a0c9111ad4106a15d2b3e",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a00dbc0b5d88eb993c91cdc08e92cdf50",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81afec5c9d4cb1dc263bc4a05291230422c",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea06d203d1c216b0d496cd008447828c14",
+"group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec",
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a14f9bce34113fee61a81ccaea5b6677b",
+"page_pulseaudio.html#autotoc_md153",
+"structpw__endpoint__link__info.html#aea87c1744850124ef9bc31d92af578f1",
+"structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1",
+"structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e",
+"structspa__loop__control.html#a392f811fbacb15de863fc0265031050f",
+"structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
