@@ -5,6 +5,9 @@ var page_pipewire_modules =
     [ "PipeWire Module: Client Device", "page_module_client_device.html", null ],
     [ "PipeWire Module: Client Node", "page_module_client_node.html", null ],
     [ "PipeWire Module: Echo Cancel", "page_module_echo_cancel.html", null ],
+    [ "PipeWire Module: Example Sink", "page_module_example_sink.html", null ],
+    [ "PipeWire Module: Example Source", "page_module_example_source.html", null ],
+    [ "PipeWire Module: Fallback Sink", "page_module_fallback_sink.html", null ],
     [ "PipeWire Module: Filter-Chain", "page_module_filter_chain.html", null ],
     [ "PipeWire Module: Link Factory", "page_module_link_factory.html", null ],
     [ "PipeWire Module: Loopback", "page_module_loopback.html", null ],
@@ -15,8 +18,11 @@ var page_pipewire_modules =
     [ "PipeWire Module: Protocol Pulse", "page_module_protocol_pulse.html", null ],
     [ "PipeWire Module: Protocol Simple", "page_module_protocol_simple.html", null ],
     [ "PipeWire Module: Pulse Tunnel", "page_module_pulse_tunnel.html", null ],
+    [ "PipeWire Module: RAOP Discover", "page_module_raop_discover.html", null ],
+    [ "PipeWire Module: ROC sink", "page_module_roc_sink.html", null ],
+    [ "PipeWire Module: ROC source", "page_module_roc_source.html", null ],
     [ "PipeWire Module: RT", "page_module_rt.html", null ],
-    [ "PipeWire Module: RTKit", "page_module_rtkit.html", null ],
     [ "PipeWire Module: Session Manager", "page_module_session_manager.html", null ],
+    [ "PipeWire Module: X11 Bell", "page_module_x11_bell.html", null ],
     [ "PipeWire Module: Zeroconf Discover", "page_module_zeroconf_discover.html", null ]
 ];
\ No newline at end of file
